@@ -11,10 +11,7 @@ Generate reStructuredText changelog from ChangesBase instance.
 import collections
 import os
 
-from typing import Any, Dict, List, MutableMapping, Optional, Union
-
-import packaging.version
-import semantic_version
+from typing import Any, cast, Dict, List, MutableMapping, Optional, Tuple, Union
 
 from .changes import ChangesBase, FragmentResolver, PluginResolver
 from .config import ChangelogConfig, PathsConfig
@@ -22,7 +19,7 @@ from .fragment import ChangelogFragment
 from .logger import LOGGER
 from .plugins import PluginDescription
 from .rst import RstBuilder
-from .utils import is_release_version
+from .utils import collect_versions
 
 
 class ChangelogEntry:
@@ -35,12 +32,14 @@ class ChangelogEntry:
     modules: List[Any]
     plugins: Dict[Any, Any]
     changes: Dict[str, Union[str, List[str]]]
+    preludes: List[Tuple[str, str]]
 
     def __init__(self, version: str):
         self.version = version
         self.modules = []
         self.plugins = dict()
         self.changes = dict()
+        self.preludes = []
 
     def has_no_changes(self, section_names: Optional[List[str]] = None) -> bool:
         """
@@ -57,7 +56,7 @@ class ChangelogEntry:
         """
         Determine whether the entry has no content at all.
         """
-        return not self.modules and not self.plugins and self.has_no_changes()
+        return not self.modules and not self.plugins and not self.preludes and self.has_no_changes()
 
     def add_section_content(self,
                             builder: RstBuilder,
@@ -107,31 +106,6 @@ class ChangelogGenerator:
         self.plugin_resolver = changes.get_plugin_resolver(plugins)
         self.fragment_resolver = changes.get_fragment_resolver(fragments)
 
-    def version_constructor(self, version: str) -> Any:
-        """
-        Create a version object.
-        """
-        if self.config.is_collection:
-            return semantic_version.Version(version)
-        return packaging.version.Version(version)
-
-    def _collect_versions(self, after_version: Optional[str] = None,
-                          until_version: Optional[str] = None) -> List[str]:
-        """
-        Collect all versions of interest and return them as an ordered list,
-        latest to earliest.
-        """
-        result = []
-        for version in sorted(self.changes.releases, reverse=True, key=self.version_constructor):
-            if after_version is not None:
-                if self.version_constructor(version) <= self.version_constructor(after_version):
-                    continue
-            if until_version is not None:
-                if self.version_constructor(version) > self.version_constructor(until_version):
-                    continue
-            result.append(version)
-        return result
-
     @staticmethod
     def _get_entry_config(release_entries: MutableMapping[str, ChangelogEntry],
                           entry_version: str) -> ChangelogEntry:
@@ -158,7 +132,47 @@ class ChangelogGenerator:
 
             entry_config.plugins[plugin_type] += plugin_list
 
-    def collect(self, squash: bool = False, after_version: Optional[str] = None,
+    def _collect_entry(self,
+                       entry_config: ChangelogEntry,
+                       entry_version: str,
+                       versions: List[str]) -> None:
+        """
+        Do actual work of collecting data for a changelog entry.
+        """
+        entry_fragment = None
+
+        dest_changes = entry_config.changes
+
+        for version in versions:
+            release = self.changes.releases[version]
+
+            for fragment in self.fragment_resolver.resolve(release):
+                for section, lines in fragment.content.items():
+                    if section == self.config.prelude_name:
+                        prelude_content = cast(str, lines)
+                        entry_config.preludes.append((version, prelude_content))
+
+                        if entry_fragment:
+                            LOGGER.info('skipping prelude in version {} due to newer '
+                                        'prelude in version {}',
+                                        version, entry_version)
+                            continue
+
+                        # lines is a str in this case!
+                        entry_fragment = prelude_content
+                        dest_changes[section] = prelude_content
+                    else:
+                        content = dest_changes.get(section)
+                        if isinstance(content, list):
+                            content.extend(lines)
+                        else:
+                            dest_changes[section] = list(lines)
+
+            self._update_modules_plugins(entry_config, release)
+
+    def collect(self,
+                squash: bool = False,
+                after_version: Optional[str] = None,
                 until_version: Optional[str] = None) -> List[ChangelogEntry]:
         """
         Collect release entries.
@@ -169,47 +183,15 @@ class ChangelogGenerator:
         :return: An ordered mapping of versions to release entries
         """
         release_entries: MutableMapping[str, ChangelogEntry] = collections.OrderedDict()
-        entry_version = until_version or self.changes.latest_version
-        entry_fragment = None
-
-        for version in self._collect_versions(
-                after_version=after_version, until_version=until_version):
-            release = self.changes.releases[version]
-
-            if not squash:
-                if is_release_version(self.config, version):
-                    # next version is a release, it needs its own entry
-                    entry_version = version
-                    entry_fragment = None
-                elif not is_release_version(self.config, entry_version):
-                    # current version is a pre-release, next version needs its own entry
-                    entry_version = version
-                    entry_fragment = None
 
+        for entry_version, versions in collect_versions(
+                self.changes.releases,
+                self.config,
+                after_version=after_version,
+                until_version=until_version,
+                squash=squash):
             entry_config = self._get_entry_config(release_entries, entry_version)
-
-            dest_changes = entry_config.changes
-
-            for fragment in self.fragment_resolver.resolve(release):
-                for section, lines in fragment.content.items():
-                    if section == self.config.prelude_name:
-                        if entry_fragment:
-                            LOGGER.info('skipping prelude in version {} due to newer '
-                                        'prelude in version {}',
-                                        version, entry_version)
-                            continue
-
-                        # lines is a str in this case!
-                        entry_fragment = lines
-                        dest_changes[section] = lines
-                    else:
-                        content = dest_changes.get(section)
-                        if isinstance(content, list):
-                            content.extend(lines)
-                        else:
-                            dest_changes[section] = list(lines)
-
-            self._update_modules_plugins(entry_config, release)
+            self._collect_entry(entry_config, entry_version, versions)
 
         return list(release_entries.values())
 
