@@ -263,7 +263,9 @@ class ChangelogConfig:
     release_tag_re: str
     pre_release_tag_re: str
     always_refresh: str
+    ignore_other_fragment_extensions: bool
     flatmap: Optional[bool]
+    use_semantic_versioning: bool
     sections: Mapping[str, str]
 
     def __init__(self, paths: PathsConfig, collection_details: CollectionDetails, config: dict):
@@ -297,13 +299,18 @@ class ChangelogConfig:
         if always_refresh is False:
             always_refresh = 'none'
         self.always_refresh = always_refresh
+        self.ignore_other_fragment_extensions = self.config.get(
+            'ignore_other_fragment_extensions', False)
         self.flatmap = self.config.get('flatmap')
+        self.use_semantic_versioning = True
 
         # The following are only relevant for ansible-base:
         self.release_tag_re = self.config.get(
             'release_tag_re', r'((?:[\d.ab]|rc)+)')
         self.pre_release_tag_re = self.config.get(
             'pre_release_tag_re', r'(?P<pre_release>\.\d+(?:[ab]|rc)+\d*)$')
+        if not self.is_collection:
+            self.use_semantic_versioning = self.config.get('use_semantic_versioning', False)
 
         if self.changes_format not in ('classic', 'combined'):
             raise ChangelogError('changes_format must be one of "classic" and "combined"')
@@ -333,12 +340,16 @@ class ChangelogConfig:
             'prelude_section_title': self.prelude_title,
             'new_plugins_after_name': self.new_plugins_after_name,
             'trivial_section_name': self.trivial_section_name,
+            'ignore_other_fragment_extensions': self.ignore_other_fragment_extensions,
         }
         if not self.is_collection:
-            config.update({
-                'release_tag_re': self.release_tag_re,
-                'pre_release_tag_re': self.pre_release_tag_re,
-            })
+            if self.use_semantic_versioning:
+                config['use_semantic_versioning'] = True
+            else:
+                config.update({
+                    'release_tag_re': self.release_tag_re,
+                    'pre_release_tag_re': self.pre_release_tag_re,
+                })
         if self.title is not None:
             config['title'] = self.title
         should_always_refresh = (self.changes_format == 'classic')
@@ -384,6 +395,7 @@ class ChangelogConfig:
             'new_plugins_after_name': 'removed_features',
             'sections': DEFAULT_SECTIONS,
             'use_fqcn': True,
+            'ignore_other_fragment_extensions': True,
         }
         if title is not None:
             config['title'] = title
