@@ -9,7 +9,7 @@ Test basic changelog functionality: Ansible 2.9 format.
 
 import os
 
-from typing import List
+from typing import List, Optional
 
 import mock
 
@@ -652,7 +652,9 @@ New Modules
 
 
 
-def fake_ansible_doc_ansible(paths: PathsConfig, plugin_type: str,
+def fake_ansible_doc_ansible(paths: PathsConfig,
+                             playbook_dir: Optional[str],
+                             plugin_type: str,
                              plugin_names: List[str]) -> dict:
     """
     Fake ansible-doc mock for Ansible-base.
