@@ -36,7 +36,7 @@ def test_changelog_init(  # pylint: disable=redefined-outer-name
     config = diff.parse_yaml('changelogs/config.yaml')
     assert config['notesdir'] == 'fragments'
     assert config['changes_file'] == 'changelog.yaml'
-    assert config['changelog_filename_template'] == 'CHANGELOG.rst'
+    assert config['changelog_filename_template'] == '../CHANGELOG.rst'
     assert 'release_tag_re' not in config
     assert 'pre_release_tag_re' not in config
     assert config['title'] == collection_changelog.collection_name.title()
@@ -56,7 +56,7 @@ def test_changelog_release_empty(  # pylint: disable=redefined-outer-name
 
     diff = collection_changelog.diff()
     assert diff.added_dirs == []
-    assert diff.added_files == ['changelogs/CHANGELOG.rst', 'changelogs/changelog.yaml']
+    assert diff.added_files == ['CHANGELOG.rst', 'changelogs/changelog.yaml']
     assert diff.removed_dirs == []
     assert diff.removed_files == ['changelogs/fragments/1.0.0.yml']
     assert diff.changed_files == []
@@ -73,7 +73,7 @@ def test_changelog_release_empty(  # pylint: disable=redefined-outer-name
     assert 'plugins' not in changelog['releases']['1.0.0']
     assert 'codename' not in changelog['releases']['1.0.0']
 
-    assert diff.file_contents['changelogs/CHANGELOG.rst'].decode('utf-8') == (
+    assert diff.file_contents['CHANGELOG.rst'].decode('utf-8') == (
         r'''=====================
 Ansible Release Notes
 =====================
@@ -107,7 +107,7 @@ This is the first proper release.
     assert diff.added_files == []
     assert diff.removed_dirs == []
     assert diff.removed_files == []
-    assert diff.changed_files == ['changelogs/CHANGELOG.rst', 'changelogs/changelog.yaml']
+    assert diff.changed_files == ['CHANGELOG.rst', 'changelogs/changelog.yaml']
 
     changelog = diff.parse_yaml('changelogs/changelog.yaml')
     assert changelog['ancestor'] is None
@@ -119,7 +119,7 @@ This is the first proper release.
     assert 'plugins' not in changelog['releases']['1.1.0']
     assert 'codename' not in changelog['releases']['1.1.0']
 
-    assert diff.file_contents['changelogs/CHANGELOG.rst'].decode('utf-8') == (
+    assert diff.file_contents['CHANGELOG.rst'].decode('utf-8') == (
         r'''=====================
 Ansible Release Notes
 =====================
@@ -196,7 +196,7 @@ def test_changelog_release_simple(  # pylint: disable=redefined-outer-name
 
     diff = collection_changelog.diff()
     assert diff.added_dirs == []
-    assert diff.added_files == ['changelogs/CHANGELOG.rst', 'changelogs/changelog.yaml']
+    assert diff.added_files == ['CHANGELOG.rst', 'changelogs/changelog.yaml']
     assert diff.removed_dirs == []
     assert diff.removed_files == [
         'changelogs/fragments/1.0.0.yml',
@@ -239,7 +239,7 @@ def test_changelog_release_simple(  # pylint: disable=redefined-outer-name
     }
     assert 'codename' not in changelog['releases']['1.0.0']
 
-    assert diff.file_contents['changelogs/CHANGELOG.rst'].decode('utf-8') == (
+    assert diff.file_contents['CHANGELOG.rst'].decode('utf-8') == (
         r'''=========================
 Ansible 1.0 Release Notes
 =========================
@@ -267,12 +267,12 @@ New Plugins
 Lookup
 ~~~~~~
 
-- bar - A foo bar lookup
+- acme.test.bar - A foo bar lookup
 
 New Modules
 -----------
 
-- test - This is a test module
+- acme.test.test - This is a test module
 ''')
 
     # Check that regenerate doesn't change anything
@@ -315,19 +315,25 @@ New Modules
     collection_changelog.add_fragment_line(
         'test-new-fragment.yml', 'minor_changes', ['Another new fragment.'])
 
-    # Check that regenerate without --refresh doesn't change anything
+    # Check that regenerate without --refresh* doesn't change anything
     assert collection_changelog.run_tool('generate', ['-v']) == 0
     assert collection_changelog.diff().unchanged
 
-    # Check that regenerate with --refresh changes
-    assert collection_changelog.run_tool('generate', ['-v', '--refresh']) == 0
+    # Check that regenerate with --refresh-fragments does not change
+    assert collection_changelog.run_tool('generate', ['-v', '--refresh-fragments']) == 0
+
+    diff = collection_changelog.diff()
+    assert diff.unchanged
+
+    # Check that regenerate with --refresh-plugins changes
+    assert collection_changelog.run_tool('generate', ['-v', '--refresh-plugins']) == 0
 
     diff = collection_changelog.diff()
     assert diff.added_dirs == []
     assert diff.added_files == []
     assert diff.removed_dirs == []
     assert diff.removed_files == []
-    assert diff.changed_files == ['changelogs/CHANGELOG.rst', 'changelogs/changelog.yaml']
+    assert diff.changed_files == ['CHANGELOG.rst', 'changelogs/changelog.yaml']
 
     changelog = diff.parse_yaml('changelogs/changelog.yaml')
     assert changelog['releases']['1.0.0']['modules'] == [
@@ -347,7 +353,7 @@ New Modules
         ],
     }
 
-    assert diff.file_contents['changelogs/CHANGELOG.rst'].decode('utf-8') == (
+    assert diff.file_contents['CHANGELOG.rst'].decode('utf-8') == (
         r'''=========================
 Ansible 1.0 Release Notes
 =========================
@@ -375,12 +381,12 @@ New Plugins
 Lookup
 ~~~~~~
 
-- bar - A foo_bar lookup
+- acme.test.bar - A foo_bar lookup
 
 New Modules
 -----------
 
-- test - This is a TEST module
+- acme.test.test - This is a TEST module
 ''')
 
     # Update plugin descriptions for 1.1.0 beta 1
@@ -439,7 +445,7 @@ New Modules
         'changelogs/fragments/1.1.0-beta-1.yml',
         'changelogs/fragments/test-new-fragment.yml',
     ]
-    assert diff.changed_files == ['changelogs/CHANGELOG.rst', 'changelogs/changelog.yaml']
+    assert diff.changed_files == ['CHANGELOG.rst', 'changelogs/changelog.yaml']
 
     changelog = diff.parse_yaml('changelogs/changelog.yaml')
     assert changelog['ancestor'] is None
@@ -465,7 +471,7 @@ New Modules
     assert 'plugins' not in changelog['releases']['1.1.0-beta-1']
     assert 'codename' not in changelog['releases']['1.1.0-beta-1']
 
-    assert diff.file_contents['changelogs/CHANGELOG.rst'].decode('utf-8') == (
+    assert diff.file_contents['CHANGELOG.rst'].decode('utf-8') == (
         r'''=========================
 Ansible 1.1 Release Notes
 =========================
@@ -489,7 +495,7 @@ Minor Changes
 New Modules
 -----------
 
-- test_new - This is ANOTHER test module
+- acme.test.test_new - This is ANOTHER test module
 
 v1.0.0
 ======
@@ -511,12 +517,12 @@ New Plugins
 Lookup
 ~~~~~~
 
-- bar - A foo_bar lookup
+- acme.test.bar - A foo_bar lookup
 
 New Modules
 -----------
 
-- test - This is a TEST module
+- acme.test.test - This is a TEST module
 ''')
 
     # Update plugin descriptions for 1.1.0
@@ -592,7 +598,7 @@ New Modules
         'changelogs/fragments/bugfix.yml',
         'changelogs/fragments/minorchange.yml',
     ]
-    assert diff.changed_files == ['changelogs/CHANGELOG.rst', 'changelogs/changelog.yaml']
+    assert diff.changed_files == ['CHANGELOG.rst', 'changelogs/changelog.yaml']
 
     changelog = diff.parse_yaml('changelogs/changelog.yaml')
     assert changelog['ancestor'] is None
@@ -623,7 +629,7 @@ New Modules
     assert 'plugins' not in changelog['releases']['1.1.0']
     assert 'codename' not in changelog['releases']['1.1.0']
 
-    assert diff.file_contents['changelogs/CHANGELOG.rst'].decode('utf-8') == (
+    assert diff.file_contents['CHANGELOG.rst'].decode('utf-8') == (
         r'''=========================
 Ansible 1.1 Release Notes
 =========================
@@ -653,9 +659,9 @@ Bugfixes
 New Modules
 -----------
 
-- test_new - This is ANOTHER test module
-- test_new2 - This is ANOTHER test module!!!11
-- test_new3 - This is yet another test module.
+- acme.test.test_new - This is ANOTHER test module
+- acme.test.test_new2 - This is ANOTHER test module!!!11
+- acme.test.test_new3 - This is yet another test module.
 
 v1.0.0
 ======
@@ -677,12 +683,12 @@ New Plugins
 Lookup
 ~~~~~~
 
-- bar - A foo_bar lookup
+- acme.test.bar - A foo_bar lookup
 
 New Modules
 -----------
 
-- test - This is a TEST module
+- acme.test.test - This is a TEST module
 ''')
 
     # Final release 1.1.0 - should not change
@@ -698,6 +704,7 @@ New Modules
 def test_changelog_release_simple_no_galaxy(  # pylint: disable=redefined-outer-name
         collection_changelog):  # noqa: F811
     collection_changelog.config.title = 'Test Collection'
+    collection_changelog.config.use_fqcn = False
     collection_changelog.set_config(collection_changelog.config)
     collection_changelog.add_fragment_line(
         '1.0.0.yml', 'release_summary', 'This is the first proper release.')
@@ -818,7 +825,8 @@ def test_changelog_release_simple_no_galaxy(  # pylint: disable=redefined-outer-
         '--date', '2020-01-02',
         '--version', '1.0.0',
         '--is-collection', 'true',
-        # The following two options are not needed since the tool doesn't have to scan for plugins:
+        # The following two options are not needed since the tool doesn't have to scan for plugins,
+        # and since FQCNs are not used:
         # '--collection-namespace', 'cloud',
         # '--collection-name', 'sky',
         '--collection-flatmap', 'yes',
@@ -826,7 +834,7 @@ def test_changelog_release_simple_no_galaxy(  # pylint: disable=redefined-outer-
 
     diff = collection_changelog.diff()
     assert diff.added_dirs == []
-    assert diff.added_files == ['changelogs/CHANGELOG.rst', 'changelogs/changelog.yaml']
+    assert diff.added_files == ['CHANGELOG.rst', 'changelogs/changelog.yaml']
     assert diff.removed_dirs == []
     assert diff.removed_files == [
         'changelogs/fragments/1.0.0.yml',
@@ -899,7 +907,7 @@ def test_changelog_release_simple_no_galaxy(  # pylint: disable=redefined-outer-
     }
     assert 'codename' not in changelog['releases']['1.0.0']
 
-    assert diff.file_contents['changelogs/CHANGELOG.rst'].decode('utf-8') == (
+    assert diff.file_contents['CHANGELOG.rst'].decode('utf-8') == (
         r'''=============================
 Test Collection Release Notes
 =============================
@@ -1126,8 +1134,8 @@ def test_changelog_release_plugin_cache(  # pylint: disable=redefined-outer-name
     diff = collection_changelog.diff()
     assert diff.added_dirs == []
     assert diff.added_files == [
+        'CHANGELOG.rst',
         'changelogs/.plugin-cache.yaml',
-        'changelogs/CHANGELOG.rst',
         'changelogs/changelog.yaml',
     ]
     assert diff.removed_dirs == []
@@ -1171,7 +1179,7 @@ def test_changelog_release_plugin_cache(  # pylint: disable=redefined-outer-name
     assert changelog['releases']['1.0.0']['modules'][0]['description'] == 'A test module'
     assert 'version_added' not in changelog['releases']['1.0.0']['modules'][0]
 
-    assert diff.file_contents['changelogs/CHANGELOG.rst'].decode('utf-8') == (
+    assert diff.file_contents['CHANGELOG.rst'].decode('utf-8') == (
         r'''===================================
 My Amazing Collection Release Notes
 ===================================
@@ -1190,5 +1198,5 @@ This is the first proper release.
 New Modules
 -----------
 
-- test_module - A test module
+- acme.test.test_module - A test module
 ''')
